Option Strict On
Option Explicit On

Imports System
Imports System.Collections.ObjectModel

Public Class SupportIncidentCollection
   Inherits BizCollection(Of SupportIncident, SupportIncidentCollection)

   ''' <summary>
   ''' Imagine a robust architecture that 
   ''' retrieved values from the database
   ''' </summary>
   ''' <remarks></remarks>
   Public Sub Load()
      ' * Submitted/OK
      ' * Submitted/Assigned Due
      ' * Submitted/Assigned OverDue
      ' * InProcess/OK
      ' * InProcess/Resolved Due
      ' * InProcess/Resolved Overdue
      ' * Resolved/OK

      ' Submitted/Assigned Due
      Me.Add(New SupportIncident( _
               "Copier has streaks", _
               "All copies have a green streak on the color copier", _
               ApplicationData.CustomerCollection.GetCustomer("Fred", "Flinstone"), _
               SubtractFromMeetingTime(0, 26), _
               AddToMeetingTime(6, 0), _
               IncidentStatus.Submitted, IncidentSeriousness.WorksBadly, _
               Nothing))
      ' In Process/OK
      Me.Add(New SupportIncident( _
               "Toner says low after replacement", _
               "Toner light stays on after I change the toner", _
               ApplicationData.CustomerCollection.GetCustomer("Sarah", "Blue"), _
               SubtractFromMeetingTime(1, 0), _
               AddToMeetingTime(6, 0), _
               IncidentStatus.InProcess, IncidentSeriousness.StillWorks, _
               ApplicationData.EmployeeCollection.GetEmployee("Doug", "Gregory")))
      ' In process/Resolved Due
      Me.Add(New SupportIncident( _
               "Ooops", _
               "Capacinno spilled into copier", _
               ApplicationData.CustomerCollection.GetCustomer("Fred", "Flinstone"), _
               SubtractFromMeetingTime(0, 6), _
               AddToMeetingTime(0, 0), _
               IncidentStatus.InProcess, IncidentSeriousness.NotWorking, _
               ApplicationData.EmployeeCollection.GetEmployee("Doug", "Gregory")))
      ' Submitted/Assigned overdue
      Me.Add(New SupportIncident( _
               "Move to Sara's desk", _
               "Copier should be moved to Sarah Jone's cubicle", _
               ApplicationData.CustomerCollection.GetCustomer("Sarah", "Blue"), _
               SubtractFromMeetingTime(1, 0), _
               AddToMeetingTime(6, 0), _
               IncidentStatus.Submitted, IncidentSeriousness.StillWorks, _
               Nothing))
      ' Submitted/OK
      Me.Add(New SupportIncident( _
               "Whirring noise on copies", _
               "Began making bad noises yesterday", _
               ApplicationData.CustomerCollection.GetCustomer("Fred", "Flinstone"), _
               SubtractFromMeetingTime(0, 1), _
               AddToMeetingTime(6, 0), _
               IncidentStatus.Submitted, IncidentSeriousness.StillWorks, _
               Nothing))
      ' InProcess/Resolved Overdue
      Me.Add(New SupportIncident( _
               "No green", _
               "Colors look funny and green comes out grey", _
               ApplicationData.CustomerCollection.GetCustomer("Sarah", "Blue"), _
               SubtractFromMeetingTime(7, 0), _
               SubtractFromMeetingTime(1, 0), _
               IncidentStatus.InProcess, IncidentSeriousness.WorksBadly, _
               Nothing))
      ' Resolved/OK
      Me.Add(New SupportIncident( _
               "Lid broken", _
               "Lid got broken off during office party", _
               ApplicationData.CustomerCollection.GetCustomer("Burt", "Basalt"), _
               SubtractFromMeetingTime(7, 0), _
               SubtractFromMeetingTime(1, 0), _
               IncidentStatus.Resolved, IncidentSeriousness.NotWorking, _
               ApplicationData.EmployeeCollection.GetEmployee("Doug", "Gregory")))
   End Sub

   Private Shared Function SubtractFromMeetingTime(ByVal days As Int32, ByVal hours As Int32) As DateTime
      Return ApplicationData.MeetingTime - New TimeSpan(days, hours, 0, 0)
   End Function

   Private Shared Function AddToMeetingTime(ByVal days As Int32, ByVal hours As Int32) As DateTime
      Return ApplicationData.MeetingTime + New TimeSpan(days, hours, 0, 0)
   End Function

End Class
